@@ -1,13 +1,21 @@
+"""
+:date_created: 2019-08-01
+"""
 import json
+
 from datetime import date, datetime
 
 
 class MyJSONEncoder(json.JSONEncoder):
     """
-    TODO
+    Custom JSON encoder used for adding encoding support to datetime/date.
     """
 
     def default(self, obj):
+        """
+        :param obj: Object being encoded.
+        :return: Encoded format.
+        """
         if isinstance(obj, datetime):
             return obj.isoformat()
         elif isinstance(obj, date):
